##  Update SAP LeanIX Integration App (for admins)
In your ServiceNow instance, follow these steps:
  1. Go to System Applications > All Available Applications > All.
  2. Find the application with the filter criteria and search bar.
  3. Next to the application listing, select the version to install.
  4. Click Update.
